<?php

namespace Litecms\Advertisement\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Advertisement\Advertisements;

class AdvertisementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'advertisement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'advertisement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Litecms\Advertisement\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Advertisement\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\Advertisement\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\Advertisement\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.advertisement', function($app)
        {
            return $this->app->make(Advertisements::class);
        });
    }



    /**
     * Merges user's and advertisement's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.advertisement'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/advertisement.php', 'litecms.advertisement.advertisement'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\Advertisement\Commands\Advertisement::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.advertisement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/advertisement')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/advertisement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/advertisement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
